#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

# @ <SNIPPET>
import sys
from openeye import oechem
from openeye import oegrid

ifs = oechem.oemolistream(sys.argv[1])
mol = oechem.OEGraphMol()
oechem.OEReadMolecule(ifs, mol)

# @ <SNIPPET-OEMakeGridFromCenterAndExtents>
center = oechem.OEFloatArray(3)
extents = oechem.OEFloatArray(3)
spacing = 0.5
oechem.OEGetCenterAndExtents(mol, center, extents)

grid = oegrid.OEScalarGrid()
oegrid.OEMakeGridFromCenterAndExtents(grid, center, extents, spacing)
# @ </SNIPPET-OEMakeGridFromCenterAndExtents>

print("Mid: %.6f %.6f %.6f" % (grid.GetXMid(), grid.GetYMid(), grid.GetZMid()))
print("Dim: %d %d %d" % (grid.GetXDim(), grid.GetYDim(), grid.GetZDim()))
print("Spacing: %.6f" % grid.GetSpacing())
# @ </SNIPPET>
