#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem
from openeye import oedepict
from openeye import oegrapheme


###############################################################
# USED TO GENERATE CODE SNIPPETS FOR THE GRAPHEME DOCUMENTATION
###############################################################

def ImportProtein(filename):

    ifs = oechem.oemolistream()
    if not ifs.open(filename):
        oechem.OEThrow.Fatal("Unable to open %s for reading" % filename)

    mol = oechem.OEGraphMol()
    if not oechem.OEReadMolecule(ifs, mol):
        oechem.OEThrow.Fatal("Unable to read molecule in %s" % filename)

    return mol


if len(sys.argv) != 2:
    oechem.OEThrow.Usage("%s <protein>" % sys.argv[0])

protein = ImportProtein(sys.argv[1])

# @ <SNIPPET-RENDER-RAMA>
image = oedepict.OEImage(800, 600)

ramaplot = oegrapheme.OERamachandranPlot()
ramaplot.AddMolecule(protein)

oegrapheme.OERenderRamachandranPlot(image, ramaplot)
# @ </SNIPPET-RENDER-RAMA>
oedepict.OEDrawCurvedBorder(image, oedepict.OELightGreyPen, 10.0)
oedepict.OEWriteImage("RenderRamachandranPlot.svg", image)

# @ <SNIPPET-RENDER-RAMA-GENERAL>
image = oedepict.OEImage(800, 600)

ramaplot = oegrapheme.OERamachandranPlot()
ramaplot.AddMolecule(protein)

oegrapheme.OERenderRamachandranPlot(image, ramaplot, oechem.OERamaType_General)
# @ </SNIPPET-RENDER-RAMA-GENERAL>

oedepict.OEDrawCurvedBorder(image, oedepict.OELightGreyPen, 10.0)
oedepict.OEWriteImage("RenderRamachandranPlot-General.png", image)
oedepict.OEAddInteractiveIcon(image, oedepict.OEIconLocation_TopRight, 0.50)
oedepict.OEWriteImage("RenderRamachandranPlot-General.svg", image)
