#!/usr/bin/env python
# (C) 2017 OpenEye Scientific Software Inc. All rights reserved.
#
# TERMS FOR USE OF SAMPLE CODE The software below ("Sample Code") is
# provided to current licensees or subscribers of OpenEye products or
# SaaS offerings (each a "Customer").
# Customer is hereby permitted to use, copy, and modify the Sample Code,
# subject to these terms. OpenEye claims no rights to Customer's
# modifications. Modification of Sample Code is at Customer's sole and
# exclusive risk. Sample Code may require Customer to have a then
# current license or subscription to the applicable OpenEye offering.
# THE SAMPLE CODE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
# EXPRESS OR IMPLIED.  OPENEYE DISCLAIMS ALL WARRANTIES, INCLUDING, BUT
# NOT LIMITED TO, WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
# PARTICULAR PURPOSE AND NONINFRINGEMENT. In no event shall OpenEye be
# liable for any damages or liability in connection with the Sample Code
# or its use.

import sys
from openeye import oechem


def read_graph_mol(fname):
    ifs = oechem.oemolistream(fname)
    mol = oechem.OEGraphMol()
    with oechem.oemolistream(fname) as ifs:
        oechem.OEReadMolecule(ifs, mol)
    oechem.OEPlaceHydrogens(mol)
    return mol


def read_design_unit(fname):
    du = oechem.OEDesignUnit()
    oechem.OEReadDesignUnit(fname, du)
    return du


if len(sys.argv) != 3:
    oechem.OEThrow.Usage("{} <du file> <lig file>".format(sys.argv[0]))

du = read_design_unit(sys.argv[1])
lig = read_graph_mol(sys.argv[2])

# @ <SNIPPET-OEUpdateDesignUnit>
if not oechem.OEUpdateDesignUnit(du, lig, oechem.OEDesignUnitComponents_Ligand):
    oechem.OEThrow.Fatal("Error: Could not add the ligand to the OEDesignUnit.")
# @ </SNIPPET-OEUpdateDesignUnit>

# @ <SNIPPET-OESubsetDesignUnit>
ligProtDU = oechem.OEDesignUnit()
components = oechem.OEDesignUnitComponents_Protein | oechem.OEDesignUnitComponents_Ligand
if not oechem.OESubsetDesignUnit(ligProtDU, du, components):
    oechem.OEThrow.Fatal("Error: Could create a subset of the reference OEDesignUnit.")
# @ </SNIPPET-OESubsetDesignUnit>
